pull_composefs_direct

Function pull_composefs_direct 

async fn pull_composefs_direct(
    repo: &Arc<Repository<Sha512HashValue>>,
    imgref: &ImageReference,
) -> Result<PullResult<Sha512HashValue>>
Pull an image directly into the composefs repository via skopeo.

This is the default path: the image is fetched directly from the source transport (registry, oci directory, etc.) into the composefs repo without going through containers-storage first.