pull_composefs_repo

Function pull_composefs_repo 

pub(crate) async fn pull_composefs_repo(
    spec_imgref: &ImageReference,
    allow_missing_fsverity: bool,
    use_unified: bool,
) -> Result<PullRepoResult>
Pulls an image into a composefs repository at /sysroot.

When use_unified is true, the image is first pulled into bootc-owned containers-storage (so it’s available for podman run), then imported from there into the composefs repo via zero-copy reflinks.

When use_unified is false (the default), the image is pulled directly into the composefs repo via skopeo.

Checks for boot entries in the image and returns them.